# Changelog

## Unreleased

## Version 0.12b0

Released 2020-08-14

- Change package name to opentelemetry-exporter-otlp
  ([#953](https://github.com/open-telemetry/opentelemetry-python/pull/953))
- Update default port to 55680 
  ([#977](https://github.com/open-telemetry/opentelemetry-python/pull/977))

## Version 0.11b0

Released 2020-07-28

- Update span exporter to use OpenTelemetry Proto v0.4.0 ([#872](https://github.com/open-telemetry/opentelemetry-python/pull/889))

## 0.9b0

Released 2020-06-10

- Initial release
